pub struct FriLayerProof<H: MerkleHasherLifted> {
pub fri_witness: Vec<SecureField>,
pub decommitment: MerkleDecommitmentLifted<H>,
pub commitment: H::Hash,
}Expand description
Proof of an individual FRI layer.
Fields
fri_witness: Vec<SecureField>Values that the verifier needs but cannot deduce from previous computations, in the order they are needed. This complements the values that were queried. These must be supplied directly to the verifier.
decommitment: MerkleDecommitmentLifted<H>commitment: H::HashTrait Implementations
Sourceimpl<H: Clone + MerkleHasherLifted> Clone for FriLayerProof<H>
impl<H: Clone + MerkleHasherLifted> Clone for FriLayerProof<H>
Sourcefn clone(&self) -> FriLayerProof<H>
fn clone(&self) -> FriLayerProof<H>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<H: Debug + MerkleHasherLifted> Debug for FriLayerProof<H>
impl<H: Debug + MerkleHasherLifted> Debug for FriLayerProof<H>
Sourceimpl<'de, H> Deserialize<'de> for FriLayerProof<H>
impl<'de, H> Deserialize<'de> for FriLayerProof<H>
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more