FriVerifier

Struct FriVerifier 

pub struct FriVerifier<MC: MerkleChannel> { /* private fields */ }

Implementations

Source

impl<MC: MerkleChannel> FriVerifier<MC>

pub fn commit( channel: &mut MC::C, config: FriConfig, proof: FriProof<MC::H>, column_bound: CirclePolyDegreeBound, ) -> Result<Self, FriVerificationError>

Verifies the commitment stage of FRI.

column_bound should be the committed circle polynomial degree bound.

Errors

An Err will be returned if:

  • The proof contains an invalid number of FRI layers.
  • The degree of the last layer polynomial is too high.
pub fn decommit( self, first_layer_query_evals: Vec<SecureField>, ) -> Result<(), FriVerificationError>

Verifies the decommitment stage of FRI.

The query evals need to be provided in the same order as their commitment.

Panics

Panics if:

  • The queries were not yet sampled.
  • The queries were sampled on the wrong domain size.
  • There aren’t the same number of decommitted values as degree bounds.
pub fn sample_query_positions(&mut self, channel: &mut MC::C) -> Vec<usize>

Samples and returns query positions mapped by column log size.