pub struct ColumnSampleBatch {
pub point: CirclePoint<SecureField>,
pub cols_vals_randpows: Vec<NumeratorData>,
}Expand description
A batch of column samplings at a point.
Fields
point: CirclePoint<SecureField>The point at which the columns are sampled.
cols_vals_randpows: Vec<NumeratorData>The sampled column indices, their values at the point, and the random coefficient power corresponding to the fri quotient associated with (point, column_index, value).
Implementations
Sourceimpl ColumnSampleBatch
impl ColumnSampleBatch
Sourcepub fn new_vec(
samples_with_rand: &[&Vec<(PointSample, SecureField)>],
) -> Vec<Self>
pub fn new_vec( samples_with_rand: &[&Vec<(PointSample, SecureField)>], ) -> Vec<Self>