Module circle

Module circle 

Structs

CanonicCoset
A coset of the form G_{2n} + <G_n>, where G_n is the generator of the subgroup of order n.
CircleDomain
A valid domain for circle polynomial interpolation and evaluation.

Constants

MAX_CIRCLE_DOMAIN_LOG_SIZE
MIN_CIRCLE_DOMAIN_LOG_SIZE