pub struct CanonicCoset {
pub coset: Coset,
}Expand description
A coset of the form G_{2n} + <G_n>, where G_n is the generator of the subgroup of order n.
The ordering on this coset is G_2n + i * G_n.
These cosets can be used as a CircleDomain, and be interpolated on.
Note that this changes the ordering on the coset to be like CircleDomain,
which is G_{2n} + i * G_{n/2} and then -G_{2n} -i * G_{n/2}.
For example, the Xs below are a canonic coset with n=8.
X O X
O O
X X
O O
X X
O O
X O XFields
coset: CosetImplementations
Sourceimpl CanonicCoset
impl CanonicCoset
pub fn new(log_size: u32) -> Self
Sourcepub fn half_coset(&self) -> Coset
pub fn half_coset(&self) -> Coset
Gets half of the coset (its conjugate complements to the whole coset), G_{2n} + <G_{n/2}>
Sourcepub fn circle_domain(&self) -> CircleDomain
pub fn circle_domain(&self) -> CircleDomain
Gets the CircleDomain representing the same point set (in another order).
pub const fn initial_index(&self) -> CirclePointIndex
pub const fn step_size(&self) -> CirclePointIndex
pub const fn step(&self) -> CirclePoint<BaseField>
pub fn index_at(&self, index: usize) -> CirclePointIndex
pub fn at(&self, i: usize) -> CirclePoint<BaseField>