Structs
- Peek
Take While - An iterator that takes elements from the underlying Peekable while the predicate is true. Used to implement PeekableExt::peek_take_while.
Traits
Functions
- all_
unique - bit_
reverse - Performs a naive bit-reversal permutation inplace.
- bit_
reverse_ coset_ to_ circle_ domain_ order - Performs a coset-natural-order to circle-domain-bit-reversed-order permutation in-place.
- bit_
reverse_ index - Returns the bit reversed index of
iwhich is represented bylog_sizebits. - circle_
domain_ index_ to_ coset_ index - Converts an index within a
CircleDomainto the corresponding index in aCoset. - coset_
index_ to_ circle_ domain_ index - Converts an index within a
Cosetto the corresponding index in aCircleDomain. - coset_
order_ to_ circle_ domain_ order - offset_
bit_ reversed_ circle_ domain_ index - Returns the index of the offset element in a bit reversed
[crate::prover::poly::circle::CircleEvaluation] of log size
eval_log_sizerelative to a smaller domain of sizedomain_log_size. - previous_
bit_ reversed_ circle_ domain_ index - Returns the index of the previous element in a bit reversed
[crate::prover::poly::circle::CircleEvaluation] of log size
eval_log_sizerelative to a smaller domain of sizedomain_log_size. - uninit_
vec ⚠ - Safety