pub struct CircleDomain {
pub half_coset: Coset,
}Expand description
A valid domain for circle polynomial interpolation and evaluation.
Valid domains are a disjoint union of two conjugate cosets: +-C + <G_n>.
The ordering defined on this domain is C + iG_n, and then -C - iG_n.
Fields
half_coset: CosetImplementations
Sourceimpl CircleDomain
impl CircleDomain
Sourcepub const fn new(half_coset: Coset) -> Self
pub const fn new(half_coset: Coset) -> Self
Given a coset C + <G_n>, constructs the circle domain +-C + <G_n> (i.e., this coset and its conjugate).
pub fn iter( &self, ) -> Chain<CosetIterator<CirclePoint<BaseField>>, CosetIterator<CirclePoint<BaseField>>> ⓘ
Sourcepub fn iter_indices(
&self,
) -> Chain<CosetIterator<CirclePointIndex>, CosetIterator<CirclePointIndex>> ⓘ
pub fn iter_indices( &self, ) -> Chain<CosetIterator<CirclePointIndex>, CosetIterator<CirclePointIndex>> ⓘ
Iterates over point indices.
Sourcepub fn at(&self, i: usize) -> CirclePoint<BaseField>
pub fn at(&self, i: usize) -> CirclePoint<BaseField>
Returns the i th domain element.
Sourcepub fn index_at(&self, i: usize) -> CirclePointIndex
pub fn index_at(&self, i: usize) -> CirclePointIndex
Returns the CirclePointIndex of the ith domain element.
Sourcepub fn is_canonic(&self) -> bool
pub fn is_canonic(&self) -> bool
Returns true if the domain is canonic.
Canonic domains are domains with elements that are the entire set of points defined by
G_2n + <G_n> where G_n and G_2n are obtained by repeatedly doubling
crate::core::circle::M31_CIRCLE_GEN.
Sourcepub fn split(&self, log_parts: u32) -> (CircleDomain, Vec<CirclePointIndex>)
pub fn split(&self, log_parts: u32) -> (CircleDomain, Vec<CirclePointIndex>)
Splits a circle domain into a smaller CircleDomains, shifted by offsets.
pub fn shift(&self, shift: CirclePointIndex) -> CircleDomain